<?php
namespace api;
use PDO;

require_once "./config.php";

/**
 * TimelineData class
 * Define all functions which either get, update, create or delete timeline data
 */
class timelineData
{
    /**
     * Get all education data
     * @return array - Array of all education data or error message
     */
    function getEduData(): array
    {
        $conn = dbConn();
        $stmt = $conn->prepare("SELECT ID, startPeriod, endPeriod, grade, course  FROM edu ORDER BY startPeriod DESC;");
        $stmt->execute();

        // set the resulting array to associative
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        if ($result)
        {
            return $result;
        }
        return array("errorMessage" => "Error, edu data not found");
    }
    
    /**
     * Get all work data
     * @return array - Array of all work data or error message
     */
    function getWorkData(): array
    {
        $conn = dbConn();
        $stmt = $conn->prepare("SELECT startPeriod, endPeriod, companyName, area, title  FROM work ORDER BY work.startPeriod DESC;");
        $stmt->execute();

        // set the resulting array to associative
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        if ($result)
        {
            return $result;
        }
        return array("errorMessage" => "Error, work data not found");
    }

    /**
     * Update education data
     * @param string $dateFrom - Start date
     * @param string $dateTo - End date
     * @param string $grade - Grade
     * @param string $course - Course
     * @param string $id - ID of the education data
     * @return bool - True if successful, false if not
     */
    function updateEduData(string $dateFrom, string $dateTo, string $grade, string $course, string $id): bool
    {
        $conn = dbConn();
        $stmt = $conn->prepare("UPDATE edu SET startPeriod = :dateFrom, endPeriod = :dateTo, grade = :grade, course = :course WHERE ID = :id;");
        $stmt->bindParam(":dateFrom", $dateFrom);
        $stmt->bindParam(":dateTo", $dateTo);
        $stmt->bindParam(":grade", $grade);
        $stmt->bindParam(":course", $course);
        $stmt->bindParam(":id", $id);
        return $stmt->execute();
    }

}
